@@ -47,6 +47,7 @@ class Auth:
             self.secure_token = r.json()
             self.id_token = self.secure_token.get("idToken")
 
+    #! deprecated
     def attempt_api_key(self, api_key='', attempts=1):
         if not api_key:
             s = f'. Attempt {attempts} of 3' if attempts > 1 else ' from https://hub.ultralytics.com/settings/api-keys'
@@ -65,6 +66,7 @@ class Auth:
             print(emojis(f"{PREFIX}Authenticated ✅"))
             return True
 
+    #! deprecated
     def validate_api_key(self, api_key):
         auth_endpoint = f"{HUB_API_ROOT}/authorise"
 
@@ -76,10 +78,10 @@ class Auth:
         self.id_token = False
         self.api_key = api_key if r.status_code == 200 else False
 
-    def get_auth_string(self):
+    def get_auth_header(self):
         if self.id_token:
-            return {"idToken": self.id_token}
+            return {"authorization": f'Bearer {self.id_token}'}
         elif self.api_key:
-            return {"apiKey": self.api_key}
+            return {"x-api-key": self.api_key}
         else:
             return None
